BlockKind

Enum BlockKind 

#[repr(u32)]
pub enum BlockKind {
Show 1168 variants Air = 0, Stone = 1, Granite = 2, PolishedGranite = 3, Diorite = 4, PolishedDiorite = 5, Andesite = 6, PolishedAndesite = 7, GrassBlock = 8, Dirt = 9, CoarseDirt = 10, Podzol = 11, Cobblestone = 12, OakPlanks = 13, SprucePlanks = 14, BirchPlanks = 15, JunglePlanks = 16, AcaciaPlanks = 17, CherryPlanks = 18, DarkOakPlanks = 19, PaleOakWood = 20, PaleOakPlanks = 21, MangrovePlanks = 22, BambooPlanks = 23, BambooMosaic = 24, OakSapling = 25, SpruceSapling = 26, BirchSapling = 27, JungleSapling = 28, AcaciaSapling = 29, CherrySapling = 30, DarkOakSapling = 31, PaleOakSapling = 32, MangrovePropagule = 33, Bedrock = 34, Water = 35, Lava = 36, Sand = 37, SuspiciousSand = 38, RedSand = 39, Gravel = 40, SuspiciousGravel = 41, GoldOre = 42, DeepslateGoldOre = 43, IronOre = 44, DeepslateIronOre = 45, CoalOre = 46, DeepslateCoalOre = 47, NetherGoldOre = 48, OakLog = 49, SpruceLog = 50, BirchLog = 51, JungleLog = 52, AcaciaLog = 53, CherryLog = 54, DarkOakLog = 55, PaleOakLog = 56, MangroveLog = 57, MangroveRoots = 58, MuddyMangroveRoots = 59, BambooBlock = 60, StrippedSpruceLog = 61, StrippedBirchLog = 62, StrippedJungleLog = 63, StrippedAcaciaLog = 64, StrippedCherryLog = 65, StrippedDarkOakLog = 66, StrippedPaleOakLog = 67, StrippedOakLog = 68, StrippedMangroveLog = 69, StrippedBambooBlock = 70, OakWood = 71, SpruceWood = 72, BirchWood = 73, JungleWood = 74, AcaciaWood = 75, CherryWood = 76, DarkOakWood = 77, MangroveWood = 78, StrippedOakWood = 79, StrippedSpruceWood = 80, StrippedBirchWood = 81, StrippedJungleWood = 82, StrippedAcaciaWood = 83, StrippedCherryWood = 84, StrippedDarkOakWood = 85, StrippedPaleOakWood = 86, StrippedMangroveWood = 87, OakLeaves = 88, SpruceLeaves = 89, BirchLeaves = 90, JungleLeaves = 91, AcaciaLeaves = 92, CherryLeaves = 93, DarkOakLeaves = 94, PaleOakLeaves = 95, MangroveLeaves = 96, AzaleaLeaves = 97, FloweringAzaleaLeaves = 98, Sponge = 99, WetSponge = 100, Glass = 101, LapisOre = 102, DeepslateLapisOre = 103, LapisBlock = 104, Dispenser = 105, Sandstone = 106, ChiseledSandstone = 107, CutSandstone = 108, NoteBlock = 109, WhiteBed = 110, OrangeBed = 111, MagentaBed = 112, LightBlueBed = 113, YellowBed = 114, LimeBed = 115, PinkBed = 116, GrayBed = 117, LightGrayBed = 118, CyanBed = 119, PurpleBed = 120, BlueBed = 121, BrownBed = 122, GreenBed = 123, RedBed = 124, BlackBed = 125, PoweredRail = 126, DetectorRail = 127, StickyPiston = 128, Cobweb = 129, ShortGrass = 130, Fern = 131, DeadBush = 132, Bush = 133, ShortDryGrass = 134, TallDryGrass = 135, Seagrass = 136, TallSeagrass = 137, Piston = 138, PistonHead = 139, WhiteWool = 140, OrangeWool = 141, MagentaWool = 142, LightBlueWool = 143, YellowWool = 144, LimeWool = 145, PinkWool = 146, GrayWool = 147, LightGrayWool = 148, CyanWool = 149, PurpleWool = 150, BlueWool = 151, BrownWool = 152, GreenWool = 153, RedWool = 154, BlackWool = 155, MovingPiston = 156, Dandelion = 157, GoldenDandelion = 158, Torchflower = 159, Poppy = 160, BlueOrchid = 161, Allium = 162, AzureBluet = 163, RedTulip = 164, OrangeTulip = 165, WhiteTulip = 166, PinkTulip = 167, OxeyeDaisy = 168, Cornflower = 169, WitherRose = 170, LilyOfTheValley = 171, BrownMushroom = 172, RedMushroom = 173, GoldBlock = 174, IronBlock = 175, Bricks = 176, Tnt = 177, Bookshelf = 178, ChiseledBookshelf = 179, AcaciaShelf = 180, BambooShelf = 181, BirchShelf = 182, CherryShelf = 183, CrimsonShelf = 184, DarkOakShelf = 185, JungleShelf = 186, MangroveShelf = 187, OakShelf = 188, PaleOakShelf = 189, SpruceShelf = 190, WarpedShelf = 191, MossyCobblestone = 192, Obsidian = 193, Torch = 194, WallTorch = 195, Fire = 196, SoulFire = 197, Spawner = 198, CreakingHeart = 199, OakStairs = 200, Chest = 201, RedstoneWire = 202, DiamondOre = 203, DeepslateDiamondOre = 204, DiamondBlock = 205, CraftingTable = 206, Wheat = 207, Farmland = 208, Furnace = 209, OakSign = 210, SpruceSign = 211, BirchSign = 212, AcaciaSign = 213, CherrySign = 214, JungleSign = 215, DarkOakSign = 216, PaleOakSign = 217, MangroveSign = 218, BambooSign = 219, OakDoor = 220, Ladder = 221, Rail = 222, CobblestoneStairs = 223, OakWallSign = 224, SpruceWallSign = 225, BirchWallSign = 226, AcaciaWallSign = 227, CherryWallSign = 228, JungleWallSign = 229, DarkOakWallSign = 230, PaleOakWallSign = 231, MangroveWallSign = 232, BambooWallSign = 233, OakHangingSign = 234, SpruceHangingSign = 235, BirchHangingSign = 236, AcaciaHangingSign = 237, CherryHangingSign = 238, JungleHangingSign = 239, DarkOakHangingSign = 240, PaleOakHangingSign = 241, CrimsonHangingSign = 242, WarpedHangingSign = 243, MangroveHangingSign = 244, BambooHangingSign = 245, OakWallHangingSign = 246, SpruceWallHangingSign = 247, BirchWallHangingSign = 248, AcaciaWallHangingSign = 249, CherryWallHangingSign = 250, JungleWallHangingSign = 251, DarkOakWallHangingSign = 252, PaleOakWallHangingSign = 253, MangroveWallHangingSign = 254, CrimsonWallHangingSign = 255, WarpedWallHangingSign = 256, BambooWallHangingSign = 257, Lever = 258, StonePressurePlate = 259, IronDoor = 260, OakPressurePlate = 261, SprucePressurePlate = 262, BirchPressurePlate = 263, JunglePressurePlate = 264, AcaciaPressurePlate = 265, CherryPressurePlate = 266, DarkOakPressurePlate = 267, PaleOakPressurePlate = 268, MangrovePressurePlate = 269, BambooPressurePlate = 270, RedstoneOre = 271, DeepslateRedstoneOre = 272, RedstoneTorch = 273, RedstoneWallTorch = 274, StoneButton = 275, Snow = 276, Ice = 277, SnowBlock = 278, Cactus = 279, CactusFlower = 280, Clay = 281, SugarCane = 282, Jukebox = 283, OakFence = 284, Netherrack = 285, SoulSand = 286, SoulSoil = 287, Basalt = 288, PolishedBasalt = 289, SoulTorch = 290, SoulWallTorch = 291, CopperTorch = 292, CopperWallTorch = 293, Glowstone = 294, NetherPortal = 295, CarvedPumpkin = 296, JackOLantern = 297, Cake = 298, Repeater = 299, WhiteStainedGlass = 300, OrangeStainedGlass = 301, MagentaStainedGlass = 302, LightBlueStainedGlass = 303, YellowStainedGlass = 304, LimeStainedGlass = 305, PinkStainedGlass = 306, GrayStainedGlass = 307, LightGrayStainedGlass = 308, CyanStainedGlass = 309, PurpleStainedGlass = 310, BlueStainedGlass = 311, BrownStainedGlass = 312, GreenStainedGlass = 313, RedStainedGlass = 314, BlackStainedGlass = 315, OakTrapdoor = 316, SpruceTrapdoor = 317, BirchTrapdoor = 318, JungleTrapdoor = 319, AcaciaTrapdoor = 320, CherryTrapdoor = 321, DarkOakTrapdoor = 322, PaleOakTrapdoor = 323, MangroveTrapdoor = 324, BambooTrapdoor = 325, StoneBricks = 326, MossyStoneBricks = 327, CrackedStoneBricks = 328, ChiseledStoneBricks = 329, PackedMud = 330, MudBricks = 331, InfestedStone = 332, InfestedCobblestone = 333, InfestedStoneBricks = 334, InfestedMossyStoneBricks = 335, InfestedCrackedStoneBricks = 336, InfestedChiseledStoneBricks = 337, BrownMushroomBlock = 338, RedMushroomBlock = 339, MushroomStem = 340, IronBars = 341, CopperBars = 342, ExposedCopperBars = 343, WeatheredCopperBars = 344, OxidizedCopperBars = 345, WaxedCopperBars = 346, WaxedExposedCopperBars = 347, WaxedWeatheredCopperBars = 348, WaxedOxidizedCopperBars = 349, IronChain = 350, CopperChain = 351, ExposedCopperChain = 352, WeatheredCopperChain = 353, OxidizedCopperChain = 354, WaxedCopperChain = 355, WaxedExposedCopperChain = 356, WaxedWeatheredCopperChain = 357, WaxedOxidizedCopperChain = 358, GlassPane = 359, Pumpkin = 360, Melon = 361, AttachedPumpkinStem = 362, AttachedMelonStem = 363, PumpkinStem = 364, MelonStem = 365, Vine = 366, GlowLichen = 367, ResinClump = 368, OakFenceGate = 369, BrickStairs = 370, StoneBrickStairs = 371, MudBrickStairs = 372, Mycelium = 373, LilyPad = 374, ResinBlock = 375, ResinBricks = 376, ResinBrickStairs = 377, ResinBrickSlab = 378, ResinBrickWall = 379, ChiseledResinBricks = 380, NetherBricks = 381, NetherBrickFence = 382, NetherBrickStairs = 383, NetherWart = 384, EnchantingTable = 385, BrewingStand = 386, Cauldron = 387, WaterCauldron = 388, LavaCauldron = 389, PowderSnowCauldron = 390, EndPortal = 391, EndPortalFrame = 392, EndStone = 393, DragonEgg = 394, RedstoneLamp = 395, Cocoa = 396, SandstoneStairs = 397, EmeraldOre = 398, DeepslateEmeraldOre = 399, EnderChest = 400, TripwireHook = 401, Tripwire = 402, EmeraldBlock = 403, SpruceStairs = 404, BirchStairs = 405, JungleStairs = 406, CommandBlock = 407, Beacon = 408, CobblestoneWall = 409, MossyCobblestoneWall = 410, FlowerPot = 411, PottedTorchflower = 412, PottedOakSapling = 413, PottedSpruceSapling = 414, PottedBirchSapling = 415, PottedJungleSapling = 416, PottedAcaciaSapling = 417, PottedCherrySapling = 418, PottedDarkOakSapling = 419, PottedPaleOakSapling = 420, PottedMangrovePropagule = 421, PottedFern = 422, PottedDandelion = 423, PottedGoldenDandelion = 424, PottedPoppy = 425, PottedBlueOrchid = 426, PottedAllium = 427, PottedAzureBluet = 428, PottedRedTulip = 429, PottedOrangeTulip = 430, PottedWhiteTulip = 431, PottedPinkTulip = 432, PottedOxeyeDaisy = 433, PottedCornflower = 434, PottedLilyOfTheValley = 435, PottedWitherRose = 436, PottedRedMushroom = 437, PottedBrownMushroom = 438, PottedDeadBush = 439, PottedCactus = 440, Carrots = 441, Potatoes = 442, OakButton = 443, SpruceButton = 444, BirchButton = 445, JungleButton = 446, AcaciaButton = 447, CherryButton = 448, DarkOakButton = 449, PaleOakButton = 450, MangroveButton = 451, BambooButton = 452, SkeletonSkull = 453, SkeletonWallSkull = 454, WitherSkeletonSkull = 455, WitherSkeletonWallSkull = 456, ZombieHead = 457, ZombieWallHead = 458, PlayerHead = 459, PlayerWallHead = 460, CreeperHead = 461, CreeperWallHead = 462, DragonHead = 463, DragonWallHead = 464, PiglinHead = 465, PiglinWallHead = 466, Anvil = 467, ChippedAnvil = 468, DamagedAnvil = 469, TrappedChest = 470, LightWeightedPressurePlate = 471, HeavyWeightedPressurePlate = 472, Comparator = 473, DaylightDetector = 474, RedstoneBlock = 475, NetherQuartzOre = 476, Hopper = 477, QuartzBlock = 478, ChiseledQuartzBlock = 479, QuartzPillar = 480, QuartzStairs = 481, ActivatorRail = 482, Dropper = 483, WhiteTerracotta = 484, OrangeTerracotta = 485, MagentaTerracotta = 486, LightBlueTerracotta = 487, YellowTerracotta = 488, LimeTerracotta = 489, PinkTerracotta = 490, GrayTerracotta = 491, LightGrayTerracotta = 492, CyanTerracotta = 493, PurpleTerracotta = 494, BlueTerracotta = 495, BrownTerracotta = 496, GreenTerracotta = 497, RedTerracotta = 498, BlackTerracotta = 499, WhiteStainedGlassPane = 500, OrangeStainedGlassPane = 501, MagentaStainedGlassPane = 502, LightBlueStainedGlassPane = 503, YellowStainedGlassPane = 504, LimeStainedGlassPane = 505, PinkStainedGlassPane = 506, GrayStainedGlassPane = 507, LightGrayStainedGlassPane = 508, CyanStainedGlassPane = 509, PurpleStainedGlassPane = 510, BlueStainedGlassPane = 511, BrownStainedGlassPane = 512, GreenStainedGlassPane = 513, RedStainedGlassPane = 514, BlackStainedGlassPane = 515, AcaciaStairs = 516, CherryStairs = 517, DarkOakStairs = 518, PaleOakStairs = 519, MangroveStairs = 520, BambooStairs = 521, BambooMosaicStairs = 522, SlimeBlock = 523, Barrier = 524, Light = 525, IronTrapdoor = 526, Prismarine = 527, PrismarineBricks = 528, DarkPrismarine = 529, PrismarineStairs = 530, PrismarineBrickStairs = 531, DarkPrismarineStairs = 532, PrismarineSlab = 533, PrismarineBrickSlab = 534, DarkPrismarineSlab = 535, SeaLantern = 536, HayBlock = 537, WhiteCarpet = 538, OrangeCarpet = 539, MagentaCarpet = 540, LightBlueCarpet = 541, YellowCarpet = 542, LimeCarpet = 543, PinkCarpet = 544, GrayCarpet = 545, LightGrayCarpet = 546, CyanCarpet = 547, PurpleCarpet = 548, BlueCarpet = 549, BrownCarpet = 550, GreenCarpet = 551, RedCarpet = 552, BlackCarpet = 553, Terracotta = 554, CoalBlock = 555, PackedIce = 556, Sunflower = 557, Lilac = 558, RoseBush = 559, Peony = 560, TallGrass = 561, LargeFern = 562, WhiteBanner = 563, OrangeBanner = 564, MagentaBanner = 565, LightBlueBanner = 566, YellowBanner = 567, LimeBanner = 568, PinkBanner = 569, GrayBanner = 570, LightGrayBanner = 571, CyanBanner = 572, PurpleBanner = 573, BlueBanner = 574, BrownBanner = 575, GreenBanner = 576, RedBanner = 577, BlackBanner = 578, WhiteWallBanner = 579, OrangeWallBanner = 580, MagentaWallBanner = 581, LightBlueWallBanner = 582, YellowWallBanner = 583, LimeWallBanner = 584, PinkWallBanner = 585, GrayWallBanner = 586, LightGrayWallBanner = 587, CyanWallBanner = 588, PurpleWallBanner = 589, BlueWallBanner = 590, BrownWallBanner = 591, GreenWallBanner = 592, RedWallBanner = 593, BlackWallBanner = 594, RedSandstone = 595, ChiseledRedSandstone = 596, CutRedSandstone = 597, RedSandstoneStairs = 598, OakSlab = 599, SpruceSlab = 600, BirchSlab = 601, JungleSlab = 602, AcaciaSlab = 603, CherrySlab = 604, DarkOakSlab = 605, PaleOakSlab = 606, MangroveSlab = 607, BambooSlab = 608, BambooMosaicSlab = 609, StoneSlab = 610, SmoothStoneSlab = 611, SandstoneSlab = 612, CutSandstoneSlab = 613, PetrifiedOakSlab = 614, CobblestoneSlab = 615, BrickSlab = 616, StoneBrickSlab = 617, MudBrickSlab = 618, NetherBrickSlab = 619, QuartzSlab = 620, RedSandstoneSlab = 621, CutRedSandstoneSlab = 622, PurpurSlab = 623, SmoothStone = 624, SmoothSandstone = 625, SmoothQuartz = 626, SmoothRedSandstone = 627, SpruceFenceGate = 628, BirchFenceGate = 629, JungleFenceGate = 630, AcaciaFenceGate = 631, CherryFenceGate = 632, DarkOakFenceGate = 633, PaleOakFenceGate = 634, MangroveFenceGate = 635, BambooFenceGate = 636, SpruceFence = 637, BirchFence = 638, JungleFence = 639, AcaciaFence = 640, CherryFence = 641, DarkOakFence = 642, PaleOakFence = 643, MangroveFence = 644, BambooFence = 645, SpruceDoor = 646, BirchDoor = 647, JungleDoor = 648, AcaciaDoor = 649, CherryDoor = 650, DarkOakDoor = 651, PaleOakDoor = 652, MangroveDoor = 653, BambooDoor = 654, EndRod = 655, ChorusPlant = 656, ChorusFlower = 657, PurpurBlock = 658, PurpurPillar = 659, PurpurStairs = 660, EndStoneBricks = 661, TorchflowerCrop = 662, PitcherCrop = 663, PitcherPlant = 664, Beetroots = 665, DirtPath = 666, EndGateway = 667, RepeatingCommandBlock = 668, ChainCommandBlock = 669, FrostedIce = 670, MagmaBlock = 671, NetherWartBlock = 672, RedNetherBricks = 673, BoneBlock = 674, StructureVoid = 675, Observer = 676, ShulkerBox = 677, WhiteShulkerBox = 678, OrangeShulkerBox = 679, MagentaShulkerBox = 680, LightBlueShulkerBox = 681, YellowShulkerBox = 682, LimeShulkerBox = 683, PinkShulkerBox = 684, GrayShulkerBox = 685, LightGrayShulkerBox = 686, CyanShulkerBox = 687, PurpleShulkerBox = 688, BlueShulkerBox = 689, BrownShulkerBox = 690, GreenShulkerBox = 691, RedShulkerBox = 692, BlackShulkerBox = 693, WhiteGlazedTerracotta = 694, OrangeGlazedTerracotta = 695, MagentaGlazedTerracotta = 696, LightBlueGlazedTerracotta = 697, YellowGlazedTerracotta = 698, LimeGlazedTerracotta = 699, PinkGlazedTerracotta = 700, GrayGlazedTerracotta = 701, LightGrayGlazedTerracotta = 702, CyanGlazedTerracotta = 703, PurpleGlazedTerracotta = 704, BlueGlazedTerracotta = 705, BrownGlazedTerracotta = 706, GreenGlazedTerracotta = 707, RedGlazedTerracotta = 708, BlackGlazedTerracotta = 709, WhiteConcrete = 710, OrangeConcrete = 711, MagentaConcrete = 712, LightBlueConcrete = 713, YellowConcrete = 714, LimeConcrete = 715, PinkConcrete = 716, GrayConcrete = 717, LightGrayConcrete = 718, CyanConcrete = 719, PurpleConcrete = 720, BlueConcrete = 721, BrownConcrete = 722, GreenConcrete = 723, RedConcrete = 724, BlackConcrete = 725, WhiteConcretePowder = 726, OrangeConcretePowder = 727, MagentaConcretePowder = 728, LightBlueConcretePowder = 729, YellowConcretePowder = 730, LimeConcretePowder = 731, PinkConcretePowder = 732, GrayConcretePowder = 733, LightGrayConcretePowder = 734, CyanConcretePowder = 735, PurpleConcretePowder = 736, BlueConcretePowder = 737, BrownConcretePowder = 738, GreenConcretePowder = 739, RedConcretePowder = 740, BlackConcretePowder = 741, Kelp = 742, KelpPlant = 743, DriedKelpBlock = 744, TurtleEgg = 745, SnifferEgg = 746, DriedGhast = 747, DeadTubeCoralBlock = 748, DeadBrainCoralBlock = 749, DeadBubbleCoralBlock = 750, DeadFireCoralBlock = 751, DeadHornCoralBlock = 752, TubeCoralBlock = 753, BrainCoralBlock = 754, BubbleCoralBlock = 755, FireCoralBlock = 756, HornCoralBlock = 757, DeadTubeCoral = 758, DeadBrainCoral = 759, DeadBubbleCoral = 760, DeadFireCoral = 761, DeadHornCoral = 762, TubeCoral = 763, BrainCoral = 764, BubbleCoral = 765, FireCoral = 766, HornCoral = 767, DeadTubeCoralFan = 768, DeadBrainCoralFan = 769, DeadBubbleCoralFan = 770, DeadFireCoralFan = 771, DeadHornCoralFan = 772, TubeCoralFan = 773, BrainCoralFan = 774, BubbleCoralFan = 775, FireCoralFan = 776, HornCoralFan = 777, DeadTubeCoralWallFan = 778, DeadBrainCoralWallFan = 779, DeadBubbleCoralWallFan = 780, DeadFireCoralWallFan = 781, DeadHornCoralWallFan = 782, TubeCoralWallFan = 783, BrainCoralWallFan = 784, BubbleCoralWallFan = 785, FireCoralWallFan = 786, HornCoralWallFan = 787, SeaPickle = 788, BlueIce = 789, Conduit = 790, BambooSapling = 791, Bamboo = 792, PottedBamboo = 793, VoidAir = 794, CaveAir = 795, BubbleColumn = 796, PolishedGraniteStairs = 797, SmoothRedSandstoneStairs = 798, MossyStoneBrickStairs = 799, PolishedDioriteStairs = 800, MossyCobblestoneStairs = 801, EndStoneBrickStairs = 802, StoneStairs = 803, SmoothSandstoneStairs = 804, SmoothQuartzStairs = 805, GraniteStairs = 806, AndesiteStairs = 807, RedNetherBrickStairs = 808, PolishedAndesiteStairs = 809, DioriteStairs = 810, PolishedGraniteSlab = 811, SmoothRedSandstoneSlab = 812, MossyStoneBrickSlab = 813, PolishedDioriteSlab = 814, MossyCobblestoneSlab = 815, EndStoneBrickSlab = 816, SmoothSandstoneSlab = 817, SmoothQuartzSlab = 818, GraniteSlab = 819, AndesiteSlab = 820, RedNetherBrickSlab = 821, PolishedAndesiteSlab = 822, DioriteSlab = 823, BrickWall = 824, PrismarineWall = 825, RedSandstoneWall = 826, MossyStoneBrickWall = 827, GraniteWall = 828, StoneBrickWall = 829, MudBrickWall = 830, NetherBrickWall = 831, AndesiteWall = 832, RedNetherBrickWall = 833, SandstoneWall = 834, EndStoneBrickWall = 835, DioriteWall = 836, Scaffolding = 837, Loom = 838, Barrel = 839, Smoker = 840, BlastFurnace = 841, CartographyTable = 842, FletchingTable = 843, Grindstone = 844, Lectern = 845, SmithingTable = 846, Stonecutter = 847, Bell = 848, Lantern = 849, SoulLantern = 850, CopperLantern = 851, ExposedCopperLantern = 852, WeatheredCopperLantern = 853, OxidizedCopperLantern = 854, WaxedCopperLantern = 855, WaxedExposedCopperLantern = 856, WaxedWeatheredCopperLantern = 857, WaxedOxidizedCopperLantern = 858, Campfire = 859, SoulCampfire = 860, SweetBerryBush = 861, WarpedStem = 862, StrippedWarpedStem = 863, WarpedHyphae = 864, StrippedWarpedHyphae = 865, WarpedNylium = 866, WarpedFungus = 867, WarpedWartBlock = 868, WarpedRoots = 869, NetherSprouts = 870, CrimsonStem = 871, StrippedCrimsonStem = 872, CrimsonHyphae = 873, StrippedCrimsonHyphae = 874, CrimsonNylium = 875, CrimsonFungus = 876, Shroomlight = 877, WeepingVines = 878, WeepingVinesPlant = 879, TwistingVines = 880, TwistingVinesPlant = 881, CrimsonRoots = 882, CrimsonPlanks = 883, WarpedPlanks = 884, CrimsonSlab = 885, WarpedSlab = 886, CrimsonPressurePlate = 887, WarpedPressurePlate = 888, CrimsonFence = 889, WarpedFence = 890, CrimsonTrapdoor = 891, WarpedTrapdoor = 892, CrimsonFenceGate = 893, WarpedFenceGate = 894, CrimsonStairs = 895, WarpedStairs = 896, CrimsonButton = 897, WarpedButton = 898, CrimsonDoor = 899, WarpedDoor = 900, CrimsonSign = 901, WarpedSign = 902, CrimsonWallSign = 903, WarpedWallSign = 904, StructureBlock = 905, Jigsaw = 906, TestBlock = 907, TestInstanceBlock = 908, Composter = 909, Target = 910, BeeNest = 911, Beehive = 912, HoneyBlock = 913, HoneycombBlock = 914, NetheriteBlock = 915, AncientDebris = 916, CryingObsidian = 917, RespawnAnchor = 918, PottedCrimsonFungus = 919, PottedWarpedFungus = 920, PottedCrimsonRoots = 921, PottedWarpedRoots = 922, Lodestone = 923, Blackstone = 924, BlackstoneStairs = 925, BlackstoneWall = 926, BlackstoneSlab = 927, PolishedBlackstone = 928, PolishedBlackstoneBricks = 929, CrackedPolishedBlackstoneBricks = 930, ChiseledPolishedBlackstone = 931, PolishedBlackstoneBrickSlab = 932, PolishedBlackstoneBrickStairs = 933, PolishedBlackstoneBrickWall = 934, GildedBlackstone = 935, PolishedBlackstoneStairs = 936, PolishedBlackstoneSlab = 937, PolishedBlackstonePressurePlate = 938, PolishedBlackstoneButton = 939, PolishedBlackstoneWall = 940, ChiseledNetherBricks = 941, CrackedNetherBricks = 942, QuartzBricks = 943, Candle = 944, WhiteCandle = 945, OrangeCandle = 946, MagentaCandle = 947, LightBlueCandle = 948, YellowCandle = 949, LimeCandle = 950, PinkCandle = 951, GrayCandle = 952, LightGrayCandle = 953, CyanCandle = 954, PurpleCandle = 955, BlueCandle = 956, BrownCandle = 957, GreenCandle = 958, RedCandle = 959, BlackCandle = 960, CandleCake = 961, WhiteCandleCake = 962, OrangeCandleCake = 963, MagentaCandleCake = 964, LightBlueCandleCake = 965, YellowCandleCake = 966, LimeCandleCake = 967, PinkCandleCake = 968, GrayCandleCake = 969, LightGrayCandleCake = 970, CyanCandleCake = 971, PurpleCandleCake = 972, BlueCandleCake = 973, BrownCandleCake = 974, GreenCandleCake = 975, RedCandleCake = 976, BlackCandleCake = 977, AmethystBlock = 978, BuddingAmethyst = 979, AmethystCluster = 980, LargeAmethystBud = 981, MediumAmethystBud = 982, SmallAmethystBud = 983, Tuff = 984, TuffSlab = 985, TuffStairs = 986, TuffWall = 987, PolishedTuff = 988, PolishedTuffSlab = 989, PolishedTuffStairs = 990, PolishedTuffWall = 991, ChiseledTuff = 992, TuffBricks = 993, TuffBrickSlab = 994, TuffBrickStairs = 995, TuffBrickWall = 996, ChiseledTuffBricks = 997, Calcite = 998, TintedGlass = 999, PowderSnow = 1_000, SculkSensor = 1_001, CalibratedSculkSensor = 1_002, Sculk = 1_003, SculkVein = 1_004, SculkCatalyst = 1_005, SculkShrieker = 1_006, CopperBlock = 1_007, ExposedCopper = 1_008, WeatheredCopper = 1_009, OxidizedCopper = 1_010, CopperOre = 1_011, DeepslateCopperOre = 1_012, OxidizedCutCopper = 1_013, WeatheredCutCopper = 1_014, ExposedCutCopper = 1_015, CutCopper = 1_016, OxidizedChiseledCopper = 1_017, WeatheredChiseledCopper = 1_018, ExposedChiseledCopper = 1_019, ChiseledCopper = 1_020, WaxedOxidizedChiseledCopper = 1_021, WaxedWeatheredChiseledCopper = 1_022, WaxedExposedChiseledCopper = 1_023, WaxedChiseledCopper = 1_024, OxidizedCutCopperStairs = 1_025, WeatheredCutCopperStairs = 1_026, ExposedCutCopperStairs = 1_027, CutCopperStairs = 1_028, OxidizedCutCopperSlab = 1_029, WeatheredCutCopperSlab = 1_030, ExposedCutCopperSlab = 1_031, CutCopperSlab = 1_032, WaxedCopperBlock = 1_033, WaxedWeatheredCopper = 1_034, WaxedExposedCopper = 1_035, WaxedOxidizedCopper = 1_036, WaxedOxidizedCutCopper = 1_037, WaxedWeatheredCutCopper = 1_038, WaxedExposedCutCopper = 1_039, WaxedCutCopper = 1_040, WaxedOxidizedCutCopperStairs = 1_041, WaxedWeatheredCutCopperStairs = 1_042, WaxedExposedCutCopperStairs = 1_043, WaxedCutCopperStairs = 1_044, WaxedOxidizedCutCopperSlab = 1_045, WaxedWeatheredCutCopperSlab = 1_046, WaxedExposedCutCopperSlab = 1_047, WaxedCutCopperSlab = 1_048, CopperDoor = 1_049, ExposedCopperDoor = 1_050, OxidizedCopperDoor = 1_051, WeatheredCopperDoor = 1_052, WaxedCopperDoor = 1_053, WaxedExposedCopperDoor = 1_054, WaxedOxidizedCopperDoor = 1_055, WaxedWeatheredCopperDoor = 1_056, CopperTrapdoor = 1_057, ExposedCopperTrapdoor = 1_058, OxidizedCopperTrapdoor = 1_059, WeatheredCopperTrapdoor = 1_060, WaxedCopperTrapdoor = 1_061, WaxedExposedCopperTrapdoor = 1_062, WaxedOxidizedCopperTrapdoor = 1_063, WaxedWeatheredCopperTrapdoor = 1_064, CopperGrate = 1_065, ExposedCopperGrate = 1_066, WeatheredCopperGrate = 1_067, OxidizedCopperGrate = 1_068, WaxedCopperGrate = 1_069, WaxedExposedCopperGrate = 1_070, WaxedWeatheredCopperGrate = 1_071, WaxedOxidizedCopperGrate = 1_072, CopperBulb = 1_073, ExposedCopperBulb = 1_074, WeatheredCopperBulb = 1_075, OxidizedCopperBulb = 1_076, WaxedCopperBulb = 1_077, WaxedExposedCopperBulb = 1_078, WaxedWeatheredCopperBulb = 1_079, WaxedOxidizedCopperBulb = 1_080, CopperChest = 1_081, ExposedCopperChest = 1_082, WeatheredCopperChest = 1_083, OxidizedCopperChest = 1_084, WaxedCopperChest = 1_085, WaxedExposedCopperChest = 1_086, WaxedWeatheredCopperChest = 1_087, WaxedOxidizedCopperChest = 1_088, CopperGolemStatue = 1_089, ExposedCopperGolemStatue = 1_090, WeatheredCopperGolemStatue = 1_091, OxidizedCopperGolemStatue = 1_092, WaxedCopperGolemStatue = 1_093, WaxedExposedCopperGolemStatue = 1_094, WaxedWeatheredCopperGolemStatue = 1_095, WaxedOxidizedCopperGolemStatue = 1_096, LightningRod = 1_097, ExposedLightningRod = 1_098, WeatheredLightningRod = 1_099, OxidizedLightningRod = 1_100, WaxedLightningRod = 1_101, WaxedExposedLightningRod = 1_102, WaxedWeatheredLightningRod = 1_103, WaxedOxidizedLightningRod = 1_104, PointedDripstone = 1_105, DripstoneBlock = 1_106, CaveVines = 1_107, CaveVinesPlant = 1_108, SporeBlossom = 1_109, Azalea = 1_110, FloweringAzalea = 1_111, MossCarpet = 1_112, PinkPetals = 1_113, Wildflowers = 1_114, LeafLitter = 1_115, MossBlock = 1_116, BigDripleaf = 1_117, BigDripleafStem = 1_118, SmallDripleaf = 1_119, HangingRoots = 1_120, RootedDirt = 1_121, Mud = 1_122, Deepslate = 1_123, CobbledDeepslate = 1_124, CobbledDeepslateStairs = 1_125, CobbledDeepslateSlab = 1_126, CobbledDeepslateWall = 1_127, PolishedDeepslate = 1_128, PolishedDeepslateStairs = 1_129, PolishedDeepslateSlab = 1_130, PolishedDeepslateWall = 1_131, DeepslateTiles = 1_132, DeepslateTileStairs = 1_133, DeepslateTileSlab = 1_134, DeepslateTileWall = 1_135, DeepslateBricks = 1_136, DeepslateBrickStairs = 1_137, DeepslateBrickSlab = 1_138, DeepslateBrickWall = 1_139, ChiseledDeepslate = 1_140, CrackedDeepslateBricks = 1_141, CrackedDeepslateTiles = 1_142, InfestedDeepslate = 1_143, SmoothBasalt = 1_144, RawIronBlock = 1_145, RawCopperBlock = 1_146, RawGoldBlock = 1_147, PottedAzaleaBush = 1_148, PottedFloweringAzaleaBush = 1_149, OchreFroglight = 1_150, VerdantFroglight = 1_151, PearlescentFroglight = 1_152, Frogspawn = 1_153, ReinforcedDeepslate = 1_154, DecoratedPot = 1_155, Crafter = 1_156, TrialSpawner = 1_157, Vault = 1_158, HeavyCore = 1_159, PaleMossBlock = 1_160, PaleMossCarpet = 1_161, PaleHangingMoss = 1_162, OpenEyeblossom = 1_163, ClosedEyeblossom = 1_164, PottedOpenEyeblossom = 1_165, PottedClosedEyeblossom = 1_166, FireflyBush = 1_167,
}
An enum of every type of block in the game.

To represent a block state, use azalea_block::BlockState or azalea_block::BlockTrait.

Variants



Air = 0



Stone = 1



Granite = 2



PolishedGranite = 3



Diorite = 4



PolishedDiorite = 5



Andesite = 6



PolishedAndesite = 7



GrassBlock = 8



Dirt = 9



CoarseDirt = 10



Podzol = 11



Cobblestone = 12



OakPlanks = 13



SprucePlanks = 14



BirchPlanks = 15



JunglePlanks = 16



AcaciaPlanks = 17



CherryPlanks = 18



DarkOakPlanks = 19



PaleOakWood = 20



PaleOakPlanks = 21



MangrovePlanks = 22



BambooPlanks = 23



BambooMosaic = 24



OakSapling = 25



SpruceSapling = 26



BirchSapling = 27



JungleSapling = 28



AcaciaSapling = 29



CherrySapling = 30



DarkOakSapling = 31



PaleOakSapling = 32



MangrovePropagule = 33



Bedrock = 34



Water = 35



Lava = 36



Sand = 37



SuspiciousSand = 38



RedSand = 39



Gravel = 40



SuspiciousGravel = 41



GoldOre = 42



DeepslateGoldOre = 43



IronOre = 44



DeepslateIronOre = 45



CoalOre = 46



DeepslateCoalOre = 47



NetherGoldOre = 48



OakLog = 49



SpruceLog = 50



BirchLog = 51



JungleLog = 52



AcaciaLog = 53



CherryLog = 54



DarkOakLog = 55



PaleOakLog = 56



MangroveLog = 57



MangroveRoots = 58



MuddyMangroveRoots = 59



BambooBlock = 60



StrippedSpruceLog = 61



StrippedBirchLog = 62



StrippedJungleLog = 63



StrippedAcaciaLog = 64



StrippedCherryLog = 65



StrippedDarkOakLog = 66



StrippedPaleOakLog = 67



StrippedOakLog = 68



StrippedMangroveLog = 69



StrippedBambooBlock = 70



OakWood = 71



SpruceWood = 72



BirchWood = 73



JungleWood = 74



AcaciaWood = 75



CherryWood = 76



DarkOakWood = 77



MangroveWood = 78



StrippedOakWood = 79



StrippedSpruceWood = 80



StrippedBirchWood = 81



StrippedJungleWood = 82



StrippedAcaciaWood = 83



StrippedCherryWood = 84



StrippedDarkOakWood = 85



StrippedPaleOakWood = 86



StrippedMangroveWood = 87



OakLeaves = 88



SpruceLeaves = 89



BirchLeaves = 90



JungleLeaves = 91



AcaciaLeaves = 92



CherryLeaves = 93



DarkOakLeaves = 94



PaleOakLeaves = 95



MangroveLeaves = 96



AzaleaLeaves = 97



FloweringAzaleaLeaves = 98



Sponge = 99



WetSponge = 100



Glass = 101



LapisOre = 102



DeepslateLapisOre = 103



LapisBlock = 104



Dispenser = 105



Sandstone = 106



ChiseledSandstone = 107



CutSandstone = 108



NoteBlock = 109



WhiteBed = 110



OrangeBed = 111



MagentaBed = 112



LightBlueBed = 113



YellowBed = 114



LimeBed = 115



PinkBed = 116



GrayBed = 117



LightGrayBed = 118



CyanBed = 119



PurpleBed = 120



BlueBed = 121



BrownBed = 122



GreenBed = 123



RedBed = 124



BlackBed = 125



PoweredRail = 126



DetectorRail = 127



StickyPiston = 128



Cobweb = 129



ShortGrass = 130



Fern = 131



DeadBush = 132



Bush = 133



ShortDryGrass = 134



TallDryGrass = 135



Seagrass = 136



TallSeagrass = 137



Piston = 138



PistonHead = 139



WhiteWool = 140



OrangeWool = 141



MagentaWool = 142



LightBlueWool = 143



YellowWool = 144



LimeWool = 145



PinkWool = 146



GrayWool = 147



LightGrayWool = 148



CyanWool = 149



PurpleWool = 150



BlueWool = 151



BrownWool = 152



GreenWool = 153



RedWool = 154



BlackWool = 155



MovingPiston = 156



Dandelion = 157



GoldenDandelion = 158



Torchflower = 159



Poppy = 160



BlueOrchid = 161



Allium = 162



AzureBluet = 163



RedTulip = 164



OrangeTulip = 165



WhiteTulip = 166



PinkTulip = 167



OxeyeDaisy = 168



Cornflower = 169



WitherRose = 170



LilyOfTheValley = 171



BrownMushroom = 172



RedMushroom = 173



GoldBlock = 174



IronBlock = 175



Bricks = 176



Tnt = 177



Bookshelf = 178



ChiseledBookshelf = 179



AcaciaShelf = 180



BambooShelf = 181



BirchShelf = 182



CherryShelf = 183



CrimsonShelf = 184



DarkOakShelf = 185



JungleShelf = 186



MangroveShelf = 187



OakShelf = 188



PaleOakShelf = 189



SpruceShelf = 190



WarpedShelf = 191



MossyCobblestone = 192



Obsidian = 193



Torch = 194



WallTorch = 195



Fire = 196



SoulFire = 197



Spawner = 198



CreakingHeart = 199



OakStairs = 200



Chest = 201



RedstoneWire = 202



DiamondOre = 203



DeepslateDiamondOre = 204



DiamondBlock = 205



CraftingTable = 206



Wheat = 207



Farmland = 208



Furnace = 209



OakSign = 210



SpruceSign = 211



BirchSign = 212



AcaciaSign = 213



CherrySign = 214



JungleSign = 215



DarkOakSign = 216



PaleOakSign = 217



MangroveSign = 218



BambooSign = 219



OakDoor = 220



Ladder = 221



Rail = 222



CobblestoneStairs = 223



OakWallSign = 224



SpruceWallSign = 225



BirchWallSign = 226



AcaciaWallSign = 227



CherryWallSign = 228



JungleWallSign = 229



DarkOakWallSign = 230



PaleOakWallSign = 231



MangroveWallSign = 232



BambooWallSign = 233



OakHangingSign = 234



SpruceHangingSign = 235



BirchHangingSign = 236



AcaciaHangingSign = 237



CherryHangingSign = 238



JungleHangingSign = 239



DarkOakHangingSign = 240



PaleOakHangingSign = 241



CrimsonHangingSign = 242



WarpedHangingSign = 243



MangroveHangingSign = 244



BambooHangingSign = 245



OakWallHangingSign = 246



SpruceWallHangingSign = 247



BirchWallHangingSign = 248



AcaciaWallHangingSign = 249



CherryWallHangingSign = 250



JungleWallHangingSign = 251



DarkOakWallHangingSign = 252



PaleOakWallHangingSign = 253



MangroveWallHangingSign = 254



CrimsonWallHangingSign = 255



WarpedWallHangingSign = 256



BambooWallHangingSign = 257



Lever = 258



StonePressurePlate = 259



IronDoor = 260



OakPressurePlate = 261



SprucePressurePlate = 262



BirchPressurePlate = 263



JunglePressurePlate = 264



AcaciaPressurePlate = 265



CherryPressurePlate = 266



DarkOakPressurePlate = 267



PaleOakPressurePlate = 268



MangrovePressurePlate = 269



BambooPressurePlate = 270



RedstoneOre = 271



DeepslateRedstoneOre = 272



RedstoneTorch = 273



RedstoneWallTorch = 274



StoneButton = 275



Snow = 276



Ice = 277



SnowBlock = 278



Cactus = 279



CactusFlower = 280



Clay = 281



SugarCane = 282



Jukebox = 283



OakFence = 284



Netherrack = 285



SoulSand = 286



SoulSoil = 287



Basalt = 288



PolishedBasalt = 289



SoulTorch = 290



SoulWallTorch = 291



CopperTorch = 292



CopperWallTorch = 293



Glowstone = 294



NetherPortal = 295



CarvedPumpkin = 296



JackOLantern = 297



Cake = 298



Repeater = 299



WhiteStainedGlass = 300



OrangeStainedGlass = 301



MagentaStainedGlass = 302



LightBlueStainedGlass = 303



YellowStainedGlass = 304



LimeStainedGlass = 305



PinkStainedGlass = 306



GrayStainedGlass = 307



LightGrayStainedGlass = 308



CyanStainedGlass = 309



PurpleStainedGlass = 310



BlueStainedGlass = 311



BrownStainedGlass = 312



GreenStainedGlass = 313



RedStainedGlass = 314



BlackStainedGlass = 315



OakTrapdoor = 316



SpruceTrapdoor = 317



BirchTrapdoor = 318



JungleTrapdoor = 319



AcaciaTrapdoor = 320



CherryTrapdoor = 321



DarkOakTrapdoor = 322



PaleOakTrapdoor = 323



MangroveTrapdoor = 324



BambooTrapdoor = 325



StoneBricks = 326



MossyStoneBricks = 327



CrackedStoneBricks = 328



ChiseledStoneBricks = 329



PackedMud = 330



MudBricks = 331



InfestedStone = 332



InfestedCobblestone = 333



InfestedStoneBricks = 334



InfestedMossyStoneBricks = 335



InfestedCrackedStoneBricks = 336



InfestedChiseledStoneBricks = 337



BrownMushroomBlock = 338



RedMushroomBlock = 339



MushroomStem = 340



IronBars = 341



CopperBars = 342



ExposedCopperBars = 343



WeatheredCopperBars = 344



OxidizedCopperBars = 345



WaxedCopperBars = 346



WaxedExposedCopperBars = 347



WaxedWeatheredCopperBars = 348



WaxedOxidizedCopperBars = 349



IronChain = 350



CopperChain = 351



ExposedCopperChain = 352



WeatheredCopperChain = 353



OxidizedCopperChain = 354



WaxedCopperChain = 355



WaxedExposedCopperChain = 356



WaxedWeatheredCopperChain = 357



WaxedOxidizedCopperChain = 358



GlassPane = 359



Pumpkin = 360



Melon = 361



AttachedPumpkinStem = 362



AttachedMelonStem = 363



PumpkinStem = 364



MelonStem = 365



Vine = 366



GlowLichen = 367



ResinClump = 368



OakFenceGate = 369



BrickStairs = 370



StoneBrickStairs = 371



MudBrickStairs = 372



Mycelium = 373



LilyPad = 374



ResinBlock = 375



ResinBricks = 376



ResinBrickStairs = 377



ResinBrickSlab = 378



ResinBrickWall = 379



ChiseledResinBricks = 380



NetherBricks = 381



NetherBrickFence = 382



NetherBrickStairs = 383



NetherWart = 384



EnchantingTable = 385



BrewingStand = 386



Cauldron = 387



WaterCauldron = 388



LavaCauldron = 389



PowderSnowCauldron = 390



EndPortal = 391



EndPortalFrame = 392



EndStone = 393



DragonEgg = 394



RedstoneLamp = 395



Cocoa = 396



SandstoneStairs = 397



EmeraldOre = 398



DeepslateEmeraldOre = 399



EnderChest = 400



TripwireHook = 401



Tripwire = 402



EmeraldBlock = 403



SpruceStairs = 404



BirchStairs = 405



JungleStairs = 406



CommandBlock = 407



Beacon = 408



CobblestoneWall = 409



MossyCobblestoneWall = 410



FlowerPot = 411



PottedTorchflower = 412



PottedOakSapling = 413



PottedSpruceSapling = 414



PottedBirchSapling = 415



PottedJungleSapling = 416



PottedAcaciaSapling = 417



PottedCherrySapling = 418



PottedDarkOakSapling = 419



PottedPaleOakSapling = 420



PottedMangrovePropagule = 421



PottedFern = 422



PottedDandelion = 423



PottedGoldenDandelion = 424



PottedPoppy = 425



PottedBlueOrchid = 426



PottedAllium = 427



PottedAzureBluet = 428



PottedRedTulip = 429



PottedOrangeTulip = 430



PottedWhiteTulip = 431



PottedPinkTulip = 432



PottedOxeyeDaisy = 433



PottedCornflower = 434



PottedLilyOfTheValley = 435



PottedWitherRose = 436



PottedRedMushroom = 437



PottedBrownMushroom = 438



PottedDeadBush = 439



PottedCactus = 440



Carrots = 441



Potatoes = 442



OakButton = 443



SpruceButton = 444



BirchButton = 445



JungleButton = 446



AcaciaButton = 447



CherryButton = 448



DarkOakButton = 449



PaleOakButton = 450



MangroveButton = 451



BambooButton = 452



SkeletonSkull = 453



SkeletonWallSkull = 454



WitherSkeletonSkull = 455



WitherSkeletonWallSkull = 456



ZombieHead = 457



ZombieWallHead = 458



PlayerHead = 459



PlayerWallHead = 460



CreeperHead = 461



CreeperWallHead = 462



DragonHead = 463



DragonWallHead = 464



PiglinHead = 465



PiglinWallHead = 466



Anvil = 467



ChippedAnvil = 468



DamagedAnvil = 469



TrappedChest = 470



LightWeightedPressurePlate = 471



HeavyWeightedPressurePlate = 472



Comparator = 473



DaylightDetector = 474



RedstoneBlock = 475



NetherQuartzOre = 476



Hopper = 477



QuartzBlock = 478



ChiseledQuartzBlock = 479



QuartzPillar = 480



QuartzStairs = 481



ActivatorRail = 482



Dropper = 483



WhiteTerracotta = 484



OrangeTerracotta = 485



MagentaTerracotta = 486



LightBlueTerracotta = 487



YellowTerracotta = 488



LimeTerracotta = 489



PinkTerracotta = 490



GrayTerracotta = 491



LightGrayTerracotta = 492



CyanTerracotta = 493



PurpleTerracotta = 494



BlueTerracotta = 495



BrownTerracotta = 496



GreenTerracotta = 497



RedTerracotta = 498



BlackTerracotta = 499



WhiteStainedGlassPane = 500



OrangeStainedGlassPane = 501



MagentaStainedGlassPane = 502



LightBlueStainedGlassPane = 503



YellowStainedGlassPane = 504



LimeStainedGlassPane = 505



PinkStainedGlassPane = 506



GrayStainedGlassPane = 507



LightGrayStainedGlassPane = 508



CyanStainedGlassPane = 509



PurpleStainedGlassPane = 510



BlueStainedGlassPane = 511



BrownStainedGlassPane = 512



GreenStainedGlassPane = 513



RedStainedGlassPane = 514



BlackStainedGlassPane = 515



AcaciaStairs = 516



CherryStairs = 517



DarkOakStairs = 518



PaleOakStairs = 519



MangroveStairs = 520



BambooStairs = 521



BambooMosaicStairs = 522



SlimeBlock = 523



Barrier = 524



Light = 525



IronTrapdoor = 526



Prismarine = 527



PrismarineBricks = 528



DarkPrismarine = 529



PrismarineStairs = 530



PrismarineBrickStairs = 531



DarkPrismarineStairs = 532



PrismarineSlab = 533



PrismarineBrickSlab = 534



DarkPrismarineSlab = 535



SeaLantern = 536



HayBlock = 537



WhiteCarpet = 538



OrangeCarpet = 539



MagentaCarpet = 540



LightBlueCarpet = 541



YellowCarpet = 542



LimeCarpet = 543



PinkCarpet = 544



GrayCarpet = 545



LightGrayCarpet = 546



CyanCarpet = 547



PurpleCarpet = 548



BlueCarpet = 549



BrownCarpet = 550



GreenCarpet = 551



RedCarpet = 552



BlackCarpet = 553



Terracotta = 554



CoalBlock = 555



PackedIce = 556



Sunflower = 557



Lilac = 558



RoseBush = 559



Peony = 560



TallGrass = 561



LargeFern = 562



WhiteBanner = 563



OrangeBanner = 564



MagentaBanner = 565



LightBlueBanner = 566



YellowBanner = 567



LimeBanner = 568



PinkBanner = 569



GrayBanner = 570



LightGrayBanner = 571



CyanBanner = 572



PurpleBanner = 573



BlueBanner = 574



BrownBanner = 575



GreenBanner = 576



RedBanner = 577



BlackBanner = 578



WhiteWallBanner = 579



OrangeWallBanner = 580



MagentaWallBanner = 581



LightBlueWallBanner = 582



YellowWallBanner = 583



LimeWallBanner = 584



PinkWallBanner = 585



GrayWallBanner = 586



LightGrayWallBanner = 587



CyanWallBanner = 588



PurpleWallBanner = 589



BlueWallBanner = 590



BrownWallBanner = 591



GreenWallBanner = 592



RedWallBanner = 593



BlackWallBanner = 594



RedSandstone = 595



ChiseledRedSandstone = 596



CutRedSandstone = 597



RedSandstoneStairs = 598



OakSlab = 599



SpruceSlab = 600



BirchSlab = 601



JungleSlab = 602



AcaciaSlab = 603



CherrySlab = 604



DarkOakSlab = 605



PaleOakSlab = 606



MangroveSlab = 607



BambooSlab = 608



BambooMosaicSlab = 609



StoneSlab = 610



SmoothStoneSlab = 611



SandstoneSlab = 612



CutSandstoneSlab = 613



PetrifiedOakSlab = 614



CobblestoneSlab = 615



BrickSlab = 616



StoneBrickSlab = 617



MudBrickSlab = 618



NetherBrickSlab = 619



QuartzSlab = 620



RedSandstoneSlab = 621



CutRedSandstoneSlab = 622



PurpurSlab = 623



SmoothStone = 624



SmoothSandstone = 625



SmoothQuartz = 626



SmoothRedSandstone = 627



SpruceFenceGate = 628



BirchFenceGate = 629



JungleFenceGate = 630



AcaciaFenceGate = 631



CherryFenceGate = 632



DarkOakFenceGate = 633



PaleOakFenceGate = 634



MangroveFenceGate = 635



BambooFenceGate = 636



SpruceFence = 637



BirchFence = 638



JungleFence = 639



AcaciaFence = 640



CherryFence = 641



DarkOakFence = 642



PaleOakFence = 643



MangroveFence = 644



BambooFence = 645



SpruceDoor = 646



BirchDoor = 647



JungleDoor = 648



AcaciaDoor = 649



CherryDoor = 650



DarkOakDoor = 651



PaleOakDoor = 652



MangroveDoor = 653



BambooDoor = 654



EndRod = 655



ChorusPlant = 656



ChorusFlower = 657



PurpurBlock = 658



PurpurPillar = 659



PurpurStairs = 660



EndStoneBricks = 661



TorchflowerCrop = 662



PitcherCrop = 663



PitcherPlant = 664



Beetroots = 665



DirtPath = 666



EndGateway = 667



RepeatingCommandBlock = 668



ChainCommandBlock = 669



FrostedIce = 670



MagmaBlock = 671



NetherWartBlock = 672



RedNetherBricks = 673



BoneBlock = 674



StructureVoid = 675



Observer = 676



ShulkerBox = 677



WhiteShulkerBox = 678



OrangeShulkerBox = 679



MagentaShulkerBox = 680



LightBlueShulkerBox = 681



YellowShulkerBox = 682



LimeShulkerBox = 683



PinkShulkerBox = 684



GrayShulkerBox = 685



LightGrayShulkerBox = 686



CyanShulkerBox = 687



PurpleShulkerBox = 688



BlueShulkerBox = 689



BrownShulkerBox = 690



GreenShulkerBox = 691



RedShulkerBox = 692



BlackShulkerBox = 693



WhiteGlazedTerracotta = 694



OrangeGlazedTerracotta = 695



MagentaGlazedTerracotta = 696



LightBlueGlazedTerracotta = 697



YellowGlazedTerracotta = 698



LimeGlazedTerracotta = 699



PinkGlazedTerracotta = 700



GrayGlazedTerracotta = 701



LightGrayGlazedTerracotta = 702



CyanGlazedTerracotta = 703



PurpleGlazedTerracotta = 704



BlueGlazedTerracotta = 705



BrownGlazedTerracotta = 706



GreenGlazedTerracotta = 707



RedGlazedTerracotta = 708



BlackGlazedTerracotta = 709



WhiteConcrete = 710



OrangeConcrete = 711



MagentaConcrete = 712



LightBlueConcrete = 713



YellowConcrete = 714



LimeConcrete = 715



PinkConcrete = 716



GrayConcrete = 717



LightGrayConcrete = 718



CyanConcrete = 719



PurpleConcrete = 720



BlueConcrete = 721



BrownConcrete = 722



GreenConcrete = 723



RedConcrete = 724



BlackConcrete = 725



WhiteConcretePowder = 726



OrangeConcretePowder = 727



MagentaConcretePowder = 728



LightBlueConcretePowder = 729



YellowConcretePowder = 730



LimeConcretePowder = 731



PinkConcretePowder = 732



GrayConcretePowder = 733



LightGrayConcretePowder = 734



CyanConcretePowder = 735



PurpleConcretePowder = 736



BlueConcretePowder = 737



BrownConcretePowder = 738



GreenConcretePowder = 739



RedConcretePowder = 740



BlackConcretePowder = 741



Kelp = 742



KelpPlant = 743



DriedKelpBlock = 744



TurtleEgg = 745



SnifferEgg = 746



DriedGhast = 747



DeadTubeCoralBlock = 748



DeadBrainCoralBlock = 749



DeadBubbleCoralBlock = 750



DeadFireCoralBlock = 751



DeadHornCoralBlock = 752



TubeCoralBlock = 753



BrainCoralBlock = 754



BubbleCoralBlock = 755



FireCoralBlock = 756



HornCoralBlock = 757



DeadTubeCoral = 758



DeadBrainCoral = 759



DeadBubbleCoral = 760



DeadFireCoral = 761



DeadHornCoral = 762



TubeCoral = 763



BrainCoral = 764



BubbleCoral = 765



FireCoral = 766



HornCoral = 767



DeadTubeCoralFan = 768



DeadBrainCoralFan = 769



DeadBubbleCoralFan = 770



DeadFireCoralFan = 771



DeadHornCoralFan = 772



TubeCoralFan = 773



BrainCoralFan = 774



BubbleCoralFan = 775



FireCoralFan = 776



HornCoralFan = 777



DeadTubeCoralWallFan = 778



DeadBrainCoralWallFan = 779



DeadBubbleCoralWallFan = 780



DeadFireCoralWallFan = 781



DeadHornCoralWallFan = 782



TubeCoralWallFan = 783



BrainCoralWallFan = 784



BubbleCoralWallFan = 785



FireCoralWallFan = 786



HornCoralWallFan = 787



SeaPickle = 788



BlueIce = 789



Conduit = 790



BambooSapling = 791



Bamboo = 792



PottedBamboo = 793



VoidAir = 794



CaveAir = 795



BubbleColumn = 796



PolishedGraniteStairs = 797



SmoothRedSandstoneStairs = 798



MossyStoneBrickStairs = 799



PolishedDioriteStairs = 800



MossyCobblestoneStairs = 801



EndStoneBrickStairs = 802



StoneStairs = 803



SmoothSandstoneStairs = 804



SmoothQuartzStairs = 805



GraniteStairs = 806



AndesiteStairs = 807



RedNetherBrickStairs = 808



PolishedAndesiteStairs = 809



DioriteStairs = 810



PolishedGraniteSlab = 811



SmoothRedSandstoneSlab = 812



MossyStoneBrickSlab = 813



PolishedDioriteSlab = 814



MossyCobblestoneSlab = 815



EndStoneBrickSlab = 816



SmoothSandstoneSlab = 817



SmoothQuartzSlab = 818



GraniteSlab = 819



AndesiteSlab = 820



RedNetherBrickSlab = 821



PolishedAndesiteSlab = 822



DioriteSlab = 823



BrickWall = 824



PrismarineWall = 825



RedSandstoneWall = 826



MossyStoneBrickWall = 827



GraniteWall = 828



StoneBrickWall = 829



MudBrickWall = 830



NetherBrickWall = 831



AndesiteWall = 832



RedNetherBrickWall = 833



SandstoneWall = 834



EndStoneBrickWall = 835



DioriteWall = 836



Scaffolding = 837



Loom = 838



Barrel = 839



Smoker = 840



BlastFurnace = 841



CartographyTable = 842



FletchingTable = 843



Grindstone = 844



Lectern = 845



SmithingTable = 846



Stonecutter = 847



Bell = 848



Lantern = 849



SoulLantern = 850



CopperLantern = 851



ExposedCopperLantern = 852



WeatheredCopperLantern = 853



OxidizedCopperLantern = 854



WaxedCopperLantern = 855



WaxedExposedCopperLantern = 856



WaxedWeatheredCopperLantern = 857



WaxedOxidizedCopperLantern = 858



Campfire = 859



SoulCampfire = 860



SweetBerryBush = 861



WarpedStem = 862



StrippedWarpedStem = 863



WarpedHyphae = 864



StrippedWarpedHyphae = 865



WarpedNylium = 866



WarpedFungus = 867



WarpedWartBlock = 868



WarpedRoots = 869



NetherSprouts = 870



CrimsonStem = 871



StrippedCrimsonStem = 872



CrimsonHyphae = 873



StrippedCrimsonHyphae = 874



CrimsonNylium = 875



CrimsonFungus = 876



Shroomlight = 877



WeepingVines = 878



WeepingVinesPlant = 879



TwistingVines = 880



TwistingVinesPlant = 881



CrimsonRoots = 882



CrimsonPlanks = 883



WarpedPlanks = 884



CrimsonSlab = 885



WarpedSlab = 886



CrimsonPressurePlate = 887



WarpedPressurePlate = 888



CrimsonFence = 889



WarpedFence = 890



CrimsonTrapdoor = 891



WarpedTrapdoor = 892



CrimsonFenceGate = 893



WarpedFenceGate = 894



CrimsonStairs = 895



WarpedStairs = 896



CrimsonButton = 897



WarpedButton = 898



CrimsonDoor = 899



WarpedDoor = 900



CrimsonSign = 901



WarpedSign = 902



CrimsonWallSign = 903



WarpedWallSign = 904



StructureBlock = 905



Jigsaw = 906



TestBlock = 907



TestInstanceBlock = 908



Composter = 909



Target = 910



BeeNest = 911



Beehive = 912



HoneyBlock = 913



HoneycombBlock = 914



NetheriteBlock = 915



AncientDebris = 916



CryingObsidian = 917



RespawnAnchor = 918



PottedCrimsonFungus = 919



PottedWarpedFungus = 920



PottedCrimsonRoots = 921



PottedWarpedRoots = 922



Lodestone = 923



Blackstone = 924



BlackstoneStairs = 925



BlackstoneWall = 926



BlackstoneSlab = 927



PolishedBlackstone = 928



PolishedBlackstoneBricks = 929



CrackedPolishedBlackstoneBricks = 930



ChiseledPolishedBlackstone = 931



PolishedBlackstoneBrickSlab = 932



PolishedBlackstoneBrickStairs = 933



PolishedBlackstoneBrickWall = 934



GildedBlackstone = 935



PolishedBlackstoneStairs = 936



PolishedBlackstoneSlab = 937



PolishedBlackstonePressurePlate = 938



PolishedBlackstoneButton = 939



PolishedBlackstoneWall = 940



ChiseledNetherBricks = 941



CrackedNetherBricks = 942



QuartzBricks = 943



Candle = 944



WhiteCandle = 945



OrangeCandle = 946



MagentaCandle = 947



LightBlueCandle = 948



YellowCandle = 949



LimeCandle = 950



PinkCandle = 951



GrayCandle = 952



LightGrayCandle = 953



CyanCandle = 954



PurpleCandle = 955



BlueCandle = 956



BrownCandle = 957



GreenCandle = 958



RedCandle = 959



BlackCandle = 960



CandleCake = 961



WhiteCandleCake = 962



OrangeCandleCake = 963



MagentaCandleCake = 964



LightBlueCandleCake = 965



YellowCandleCake = 966



LimeCandleCake = 967



PinkCandleCake = 968



GrayCandleCake = 969



LightGrayCandleCake = 970



CyanCandleCake = 971



PurpleCandleCake = 972



BlueCandleCake = 973



BrownCandleCake = 974



GreenCandleCake = 975



RedCandleCake = 976



BlackCandleCake = 977



AmethystBlock = 978



BuddingAmethyst = 979



AmethystCluster = 980



LargeAmethystBud = 981



MediumAmethystBud = 982



SmallAmethystBud = 983



Tuff = 984



TuffSlab = 985



TuffStairs = 986



TuffWall = 987



PolishedTuff = 988



PolishedTuffSlab = 989



PolishedTuffStairs = 990



PolishedTuffWall = 991



ChiseledTuff = 992



TuffBricks = 993



TuffBrickSlab = 994



TuffBrickStairs = 995



TuffBrickWall = 996



ChiseledTuffBricks = 997



Calcite = 998



TintedGlass = 999



PowderSnow = 1_000



SculkSensor = 1_001



CalibratedSculkSensor = 1_002



Sculk = 1_003



SculkVein = 1_004



SculkCatalyst = 1_005



SculkShrieker = 1_006



CopperBlock = 1_007



ExposedCopper = 1_008



WeatheredCopper = 1_009



OxidizedCopper = 1_010



CopperOre = 1_011



DeepslateCopperOre = 1_012



OxidizedCutCopper = 1_013



WeatheredCutCopper = 1_014



ExposedCutCopper = 1_015



CutCopper = 1_016



OxidizedChiseledCopper = 1_017



WeatheredChiseledCopper = 1_018



ExposedChiseledCopper = 1_019



ChiseledCopper = 1_020



WaxedOxidizedChiseledCopper = 1_021



WaxedWeatheredChiseledCopper = 1_022



WaxedExposedChiseledCopper = 1_023



WaxedChiseledCopper = 1_024



OxidizedCutCopperStairs = 1_025



WeatheredCutCopperStairs = 1_026



ExposedCutCopperStairs = 1_027



CutCopperStairs = 1_028



OxidizedCutCopperSlab = 1_029



WeatheredCutCopperSlab = 1_030



ExposedCutCopperSlab = 1_031



CutCopperSlab = 1_032



WaxedCopperBlock = 1_033



WaxedWeatheredCopper = 1_034



WaxedExposedCopper = 1_035



WaxedOxidizedCopper = 1_036



WaxedOxidizedCutCopper = 1_037



WaxedWeatheredCutCopper = 1_038



WaxedExposedCutCopper = 1_039



WaxedCutCopper = 1_040



WaxedOxidizedCutCopperStairs = 1_041



WaxedWeatheredCutCopperStairs = 1_042



WaxedExposedCutCopperStairs = 1_043



WaxedCutCopperStairs = 1_044



WaxedOxidizedCutCopperSlab = 1_045



WaxedWeatheredCutCopperSlab = 1_046



WaxedExposedCutCopperSlab = 1_047



WaxedCutCopperSlab = 1_048



CopperDoor = 1_049



ExposedCopperDoor = 1_050



OxidizedCopperDoor = 1_051



WeatheredCopperDoor = 1_052



WaxedCopperDoor = 1_053



WaxedExposedCopperDoor = 1_054



WaxedOxidizedCopperDoor = 1_055



WaxedWeatheredCopperDoor = 1_056



CopperTrapdoor = 1_057



ExposedCopperTrapdoor = 1_058



OxidizedCopperTrapdoor = 1_059



WeatheredCopperTrapdoor = 1_060



WaxedCopperTrapdoor = 1_061



WaxedExposedCopperTrapdoor = 1_062



WaxedOxidizedCopperTrapdoor = 1_063



WaxedWeatheredCopperTrapdoor = 1_064



CopperGrate = 1_065



ExposedCopperGrate = 1_066



WeatheredCopperGrate = 1_067



OxidizedCopperGrate = 1_068



WaxedCopperGrate = 1_069



WaxedExposedCopperGrate = 1_070



WaxedWeatheredCopperGrate = 1_071



WaxedOxidizedCopperGrate = 1_072



CopperBulb = 1_073



ExposedCopperBulb = 1_074



WeatheredCopperBulb = 1_075



OxidizedCopperBulb = 1_076



WaxedCopperBulb = 1_077



WaxedExposedCopperBulb = 1_078



WaxedWeatheredCopperBulb = 1_079



WaxedOxidizedCopperBulb = 1_080



CopperChest = 1_081



ExposedCopperChest = 1_082



WeatheredCopperChest = 1_083



OxidizedCopperChest = 1_084



WaxedCopperChest = 1_085



WaxedExposedCopperChest = 1_086



WaxedWeatheredCopperChest = 1_087



WaxedOxidizedCopperChest = 1_088



CopperGolemStatue = 1_089



ExposedCopperGolemStatue = 1_090



WeatheredCopperGolemStatue = 1_091



OxidizedCopperGolemStatue = 1_092



WaxedCopperGolemStatue = 1_093



WaxedExposedCopperGolemStatue = 1_094



WaxedWeatheredCopperGolemStatue = 1_095



WaxedOxidizedCopperGolemStatue = 1_096



LightningRod = 1_097



ExposedLightningRod = 1_098



WeatheredLightningRod = 1_099



OxidizedLightningRod = 1_100



WaxedLightningRod = 1_101



WaxedExposedLightningRod = 1_102



WaxedWeatheredLightningRod = 1_103



WaxedOxidizedLightningRod = 1_104



PointedDripstone = 1_105



DripstoneBlock = 1_106



CaveVines = 1_107



CaveVinesPlant = 1_108



SporeBlossom = 1_109



Azalea = 1_110



FloweringAzalea = 1_111



MossCarpet = 1_112



PinkPetals = 1_113



Wildflowers = 1_114



LeafLitter = 1_115



MossBlock = 1_116



BigDripleaf = 1_117



BigDripleafStem = 1_118



SmallDripleaf = 1_119



HangingRoots = 1_120



RootedDirt = 1_121



Mud = 1_122



Deepslate = 1_123



CobbledDeepslate = 1_124



CobbledDeepslateStairs = 1_125



CobbledDeepslateSlab = 1_126



CobbledDeepslateWall = 1_127



PolishedDeepslate = 1_128



PolishedDeepslateStairs = 1_129



PolishedDeepslateSlab = 1_130



PolishedDeepslateWall = 1_131



DeepslateTiles = 1_132



DeepslateTileStairs = 1_133



DeepslateTileSlab = 1_134



DeepslateTileWall = 1_135



DeepslateBricks = 1_136



DeepslateBrickStairs = 1_137



DeepslateBrickSlab = 1_138



DeepslateBrickWall = 1_139



ChiseledDeepslate = 1_140



CrackedDeepslateBricks = 1_141



CrackedDeepslateTiles = 1_142



InfestedDeepslate = 1_143



SmoothBasalt = 1_144



RawIronBlock = 1_145



RawCopperBlock = 1_146



RawGoldBlock = 1_147



PottedAzaleaBush = 1_148



PottedFloweringAzaleaBush = 1_149



OchreFroglight = 1_150



VerdantFroglight = 1_151



PearlescentFroglight = 1_152



Frogspawn = 1_153



ReinforcedDeepslate = 1_154



DecoratedPot = 1_155



Crafter = 1_156



TrialSpawner = 1_157



Vault = 1_158



HeavyCore = 1_159



PaleMossBlock = 1_160



PaleMossCarpet = 1_161



PaleHangingMoss = 1_162



OpenEyeblossom = 1_163



ClosedEyeblossom = 1_164



PottedOpenEyeblossom = 1_165



PottedClosedEyeblossom = 1_166



FireflyBush = 1_167

Implementations

Source

impl BlockKind

pub unsafe fn from_u32_unchecked(id: u32) -> Self

Transmutes a u32 to a BlockKind.

Safety

The id should be at most 1167.

pub const fn is_valid_id(id: u32) -> bool

Source

impl BlockKind

pub fn to_str(&self) -> &'static str

Convert the value to a stringified identifier, formatted like "minecraft:air".